@@ -4,7 +4,8 @@ module Rack
       include AttrRequired, AttrOptional
       attr_required :access_token, :token_type, :httpclient
       attr_optional :refresh_token, :expires_in, :scope
-      delegate :get, :post, :put, :delete, to: :httpclient
+      attr_accessor :raw_attributes
+      delegate :get, :patch, :post, :put, :delete, to: :httpclient
 
       alias_method :to_s, :access_token
 
@@ -12,6 +13,7 @@ module Rack
         (required_attributes + optional_attributes).each do |key|
           self.send :"#{key}=", attributes[key]
         end
+        @raw_attributes = attributes
         @token_type = self.class.name.demodulize.underscore.to_sym
         @httpclient = Rack::OAuth2.http_client("#{self.class} (#{VERSION})") do |config|
           config.request_filter << Authenticator.new(self)
