@@ -45,6 +45,25 @@ module Rack
         )
       end
 
+      def jwt_bearer=(assertion)
+        @grant = Grant::JWTBearer.new(
+          assertion: assertion
+        )
+      end
+
+      def saml2_bearer=(assertion)
+        @grant = Grant::SAML2Bearer.new(
+          assertion: assertion
+        )
+      end
+
+      def subject_token=(subject_token, subject_token_type = URN::TokenType::JWT)
+        @grant = Grant::TokenExchange.new(
+          subject_token: subject_token,
+          subject_token_type: subject_token_type
+        )
+      end
+
       def access_token!(*args)
         headers, params = {}, @grant.as_json
 
